Select the files to be loaded above and click the **Load as corpus** button to load them. Files can be loaded one or multiple at a time.

**Note:** this does not build the corpus. The **Build corpus** button will appear after loading.